@@ -554,8 +554,9 @@ def rename_file_md5(folder,over_write=True):
         all_md5_name.append(md5_name)
         movefile(f,new_file_path)
 
-def format_file_name(file_name,pattern="[a-zA-Z0-9_\.]"):
+def format_file_name(file_name,pattern="[a-zA-Z0-9_\\.]"):
     new_file_name="".join(search_by_regular(pattern,file_name))
+    new_file_name=new_file_name.replace(".","_")
     return new_file_name
 
 def change_venv(old_project_path,new_project_path):
@@ -603,4 +604,3 @@ def split_path(file_path):
 def search_by_regular(pattern,content):
     regex = re.compile(pattern)
     return regex.findall(content)
-
